@@ -1,4 +1,4 @@
-from .base import Cache, CacheCore, CachedItemMeta, Serializer, check_meta_mismatches, logger
+from .base import Cache, CacheCore, CachedItemMeta, Serializer, check_meta_mismatches, base_logger
 from .local_cache import LocalDiskCache
 from .memory_cache import MemoryCache
 from .multi_cache import MultiCache
